#
# spec file for package git-cliff
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           git-cliff
Version:        2.9.0
Release:        1.1
Summary:        Changelog generator for git repositories
License:        (Apache-2.0 OR MIT) AND Unicode-DFS-2016 AND (0BSD OR MIT OR Apache-2.0) AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR ISC OR MIT) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT) AND (Apache-2.0 OR MIT OR Zlib) AND (Apache-2.0 OR MIT OR Zlib) AND (MIT OR Unlicense) AND (Apache-2.0 OR Zlib OR MIT) AND Apache-2.0 AND BSD-3-Clause AND ISC AND MIT AND MPL-2.0 AND GPL-3.0-only AND SUSE-GPL-2.0-with-linking-exception+
URL:            https://github.com/orhun/git-cliff
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  zstd
ExclusiveArch:  %{rust_arches}

%description
git-cliff is a utility to generate changelogs that follows the
Conventional Commit Specifications.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.

%package        bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description    bash-completion
Bash command-line completion support for %{name}.

%prep
%autosetup -a1

%build
# We don't need to check an update. github feature is nice to have though
%{cargo_build} --ignore-rust-version --no-default-features -F github
mkdir -p target/completions/
mkdir -p target/man/
OUT_DIR=target/completions/ ./target/release/%{name}-completions
OUT_DIR=target/man/ ./target/release/%{name}-mangen

%install
install -Dm755 -T ./target/release/%{name} %{buildroot}%{_bindir}/%{name}
install -Dm644 -T ./target/completions/%{name}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm644 -T ./target/completions/%{name}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish
install -Dm644 -T ./target/completions/_%{name} %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
install -Dm644 -T ./target/man/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

%files
%{_bindir}/%{name}
%{_mandir}/man1/git-cliff.1%{?ext_man}
%license LICENSE-MIT LICENSE-APACHE
%doc README.md RELEASE.md CHANGELOG.md

%files bash-completion
%{_datadir}/bash-completion/*

%files fish-completion
%dir %{_datadir}/fish
%{_datadir}/fish/*

%files zsh-completion
%dir %{_datadir}/zsh
%{_datadir}/zsh/*

%changelog
* Mon Jun  2 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 2.9.0:
  * chore(release): prepare for v2.9.0
  * docs(website): add highlights for 2.9.0 (#1153)
  * chore(deps-dev): bump typescript in /website in the patch group (#1139)
  * chore(docs): fix some typos (#1149)
  * fix(template): correctly serialize JSON for the commit fields (#1145)
  * docs(security): extend security policy (#1142)
  * chore(deps): bump the minor group in /website with 2 updates (#1116)
  * refactor(lint): apply clippy suggestions
  * feat(context): add release commit range (#1138)
  * fix(submodules): fix submodules handling when using custom range (#1136)
  * docs(config): fix typo on commit.links (#1132)
  * chore(deps): upgrade dependencies (#1129)
  * chore(project): migrate to Rust 2024 edition (#1128)
  * feat(changelog): support recursing into submodules (#1082)
  * feat(remote): fetch commits from non-default branches using remotes (#1086)
  * feat(git): support disabling sorting commits topologically (#804) (#1121)
  * refactor(config): initialize config structs with default values (#1090)
  * chore(dependabot): make dependency updates less noisy
  * chore(dependabot): check dependency updates weekly
  * fix(bump): check the next version against tag_pattern regex (#1070)
  * feat(config): support configuring with a remote URL (#1083)
  * fix(fixtures): evaluate the rc of git-cliff correctly (#1104)
  * fix(bump): accept lowercase values for bump_type config (#1101)
  * docs(readme): add blog posts from the community (#1102)
  * fix(fixtures): use the correct syntax while checking fixture results (#1099)
  * docs(website): remove references of tj-actions (#1097)
  * feat(config): add `require_conventional` option (#1061)
  * docs(release): fix Docker Hub URL
  * refactor(lint): use IOError::other (#1074)
  * doc(config): update comments for all configuration options (#1057)
  * docs(quickstart): clarify git-cliff command (#1051)
  * fix(git): handle worktrees while retrieving the path of repository (#1054)
  * chore(npm): update yarn.lock
  * fix(remote): fix detection of GitLab merge request sha if commits were squashed (#1043)
  * fix(deps): make glob dependency mandatory (#1035)
* Sun Apr 13 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 2.8.0:
  * cli: Support initializing config with a custom filename
  * config: Discover the configuration file when run in a sub directory
  * git: Improve the set commit range error
  * monorepo: Automatically set include-path for current directory
  * remote: Support enabling native TLS
  * repo: Allow running from sub directories
  * config: Allow environment overwrites when using builtin config
  * fixtures: Update the arguments for custom GitLab API fixture test
  * monorepo: Do not set include-path if workdir is set
  * remote: Fix detection of GitLab merge request sha
  * lib: Add changelog modifier callback to run function
  * lint: Use a shared lint config for the workspace
  * lint: Apply clippy suggestions
  * docker: Fix typo in comment
  * highlights: Add link to the Nix flake
  * jujutsu: Update links to the upstream documentation
  * lib: Allow doc lint
  * license: Update copyright years
  * tips: Extend the merge commit filter example
  * website: Add highlights for 2.8.0
  * fixture: Add fixture for include-path
  * build: Bump MSRV to 1.83.0
  * lint: Allow false positive lint
* Sat Dec 21 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Attempt to build by ignoring rust version.
* Sat Dec 21 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 2.7.0:
  * refactor(clippy): apply clippy suggestions
  * chore(deps): bump dependencies
  * chore(integration): remove experimental feature disclaimer
  * feat(config): allow overriding the remote API URL via config
  * docs(git): improve docs for commit_preprocessors and commit_parsers
  * feat(jujutsu): add jujustu support
  * perf(test): don't create regex inside a loop
  * chore(log): add trace log about which command is being run
  * fix(remote): preserve first time contributors
  * test(git): find upstream remote when using ssh
  * docs(readme): add blog post about git-cliff
  * chore(config): add the 'other' parser to the default config
  * fix(changelog): fix missing commit fields in context
  * refactor(clippy): apply clippy suggestions
  * test(repo): expand unit tests of the repo module
  * fix(changelog): include the root commit when `--latest` is used with one tag
  * chore(deps): bump clap from 4.5.18 to 4.5.19
  * feat(args): add color to the help text
  * chore(release): prepare for v2.6.1
  * refactor(clippy): apply doc_markdown and ignored_unit_patterns lint
  * chore(fixtures): build binaries using dev profile
  * refactor(clippy): apply if_not_else lint
  * fix(remote): avoid setting multiple remotes
  * chore(deps): bump thiserror from 1.0.63 to 1.0.64
  * refactor(clippy): apply assigning_clones lint
  * refactor(clippy): apply single_match_else lint
  * refactor(clippy): apply needless_pass_by_value lint
  * chore(release): prepare for v2.6.0
  * feat(config): add changelog.render_always option
  * chore(deps): bump dependencies
  * fix(changelog): do not change the tag date if tag already exists
  * feat(config): allow configuring output file from config
  * docs(args): fix copy-paste mistake where gitea mentioned gitlab
  * fix(commit): trim the trailing newline for git2 commits
  * fix(bump): suppress template warning when `--bumped-version` is used
  * refactor(clippy): apply explicit_iter_loop lint
  * refactor(clippy): apply manual_is_variant_and lint
  * chore(deps): bump clap_complete from 4.5.23 to 4.5.28
  * chore(deps-dev): bump typescript from 5.5.4 to 5.6.2 in /website in the minor group
  * chore(deps): bump pretty_assertions from 1.4.0 to 1.4.1
  * fix(changelog): correctly set the tag message for the latest release
  * refactor(clippy): apply case_sensitive_file_extension_comparisons lint
  * refactor(clippy): apply clippy suggestions
  * refactor(clippy): apply option_as_ref_cloned lint
  * refactor(template)!: add name parameter to the constructor
  * fix(core): avoid the unnecessary loop when no remote feature is activated
  * feat(core): add `remote` to commit and deprecate fields
  * refactor(clippy): apply semicolon_if_nothing_returned clippy lint
  * refactor(clippy): apply unnested_or_patterns clippy lint
  * docs(contributing): mention fetching the tags for running tests successfully
  * fix(args): support using use_branch_tags from both config and args
  * feat(changelog): support generating changelog for different branches
  * chore(examples): improve example templates
  * chore(lib): fix typos in code comments
  * chore(deps): bump prism-react-renderer from 2.3.1 to 2.4.0 in /website in the minor group
  * fix(template): resolve parsing issues with `raw`/`endraw` in Jinja
  * fix(changelog): don't change the context when provided via `--from-context`
* Mon Sep 16 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- update to version 2.5.0:
  * Remove unnecessary git-cliff-action output file
  * Include new contributors in repository changelog
  * Check for null commit_id in detailed templa
  * Fix comment for changelog header template
  * Update keepachangelog.toml comme
  * Clarify authentication with GitHub tok
  * Correct inverted consequences of configuration val
  * Make example templates more user-friendly
  * Clean up url encoding for GitLab
  * Allow using --bumped-version without conventional commits
  * Allow using environment variables without config file present
  * Fix fetching repository for gitlab integration test
  * URL-encode the owner in remote requests for GitLab
  * Include for-loop arguments in template variables
  * Allow GitLab groups with --gitlab-repo
  * Support bumping to a specific semver type
  * Support count_tags option
  * Skip ssh and x509 signatures in tag messages
  * Generate changelog from JSON context
  * Allow whole commit context to be used in commit parsers
  * Support performance profiling via pprof
  * Activate integration if remote is set manually
* Sat Jul  6 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.4.0:
  * Support bumping based on configurable custom pattern
  * Support setting the initial_tag
  * multiple improvements to changelog generation
  * Add Gitea support
  * Add Bitbucket support
  * Add GitLab support
  * Support using stdout via dash (-o -)
  * Bug Fixes and documentation updates
  * Add --ignore-tags argument
  * Allow -o and -p together if they point to different files
* Wed May 15 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.2.2:
  * (changelog) Allow adding custom context
  * (changelog) Ignore empty lines when using split_commits
  * (parser) Allow matching empty commit body
  * Documentation updates
* Sun May  5 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.2.1:
  * Make rendering errors more verbose
  * Support detecting config from project manifest
  * Make the bump version rules configurable
  * bug fixes and documentation updates
- CVE-2024-32650: rust-rustls: Infinite loop with proper client
  input fixes (boo#1223218)
* Thu Mar  7 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Adopt new way to package rust software with obs-service-cargo:
  * remove cargo_config. it's part of vendor.tar now
- Update to version 2.1.2:
  * feat(npm): add programmatic API for TypeScript
  * chore(fixtures): enable verbose logging for output
  * refactor(clippy): apply clippy suggestions
  * refactor(changelog): do not output to stdout when prepend is used
  * feat(args): add `--tag-pattern` argument
  * fix(config): fix commit parser regex in the default config
  * fix(github): sanitize the GitHub token in debug logs
  * chore(config): add animation to the header of the changelog
  * refactor(clippy): apply clippy suggestions
  * docs(security): update security policy
  * chore(project): add readme to core package
  * chore(embed): do not allow missing docs
  * chore(config): skip dependabot commits for dev updates
  * docs(readme): mention RustLab 2023 talk
  * chore(config): revamp the configuration files
  * chore(docker): update versions in Dockerfile
  * chore(example): use full links in GitHub templates
  * chore(project): bump MSRV to 1.74.1
  * revert(config): use postprocessors for checking the typos
  * feat(template): support using PR labels in the GitHub template
  * docs(configuration): fix typo
  * feat(args): add `--no-exec` flag for skipping command execution
  * chore(command): explicitly set the directory of command to current dir
  * refactor(ci): use hardcoded workspace members for cargo-msrv command
  * refactor(ci): simplify cargo-msrv installation
  * refactor(clippy): apply clippy suggestions
  * refactor(config): use postprocessors for checking the typos
  * chore(project): update copyright years
  * chore(github): update templates about GitHub integration
  * feat(changelog): set the timestamp of the previous release
  * feat(template): support using PR title in the GitHub template
  * feat(changelog): improve skipping via `.cliffignore` and `--skip-commit`
  * chore(changelog): disable the default behavior of next-version
  * fix(git): sort commits in topological order
  * test(changelog): use the correct version for missing tags
  * chore(changelog): use 0.1.0 as default next release if no tag is found
  * feat(github)!: support integration with GitHub repos
  * refactor(changelog): support `--bump` for processed releases
  * fix(cli): fix broken pipe when stdout is interrupted
  * test(fixtures): update the bumped value output to add prefix
  * feat(changelog): support tag prefixes with `--bump`
  * feat(changelog)!: set tag to `0.0.1` via `--bump` if no tags exist
  * fix(commit): trim the trailing newline from message
  * docs(readme): use the raw link for the animation
  * chore(example): remove limited commits example
  * feat(args): add `-x` short argument for `--context`
  * revert(deps): bump actions/upload-pages-artifact from 2 to 3
  * revert(deps): bump actions/deploy-pages from 3 to 4
  * chore(dependabot): group the dependency updates for creating less PRs
  * feat(parser): support using SHA1 of the commit
  * feat(commit): add merge_commit flag to the context
  * chore(mergify): don't update PRs for the main branch
  * fix(links): skip checking the GitHub commit URLs
  * fix(changelog): fix previous version links
  * feat(parser): support using regex scope values
  * test(fixture): update the date for example test fixture
  * docs(fixtures): add instructions for adding new fixtures
  * feat(args): support initialization with built-in templates
  * feat(changelog)!: support templating in the footer
  * feat(args): allow returning the bumped version
  * test(fixture): add test fixture for bumping version
  * fix: allow version bump with a single previous release
  * fix(changelog): set the correct previous tag when a custom tag is given
  * feat(args): set `CHANGELOG.md` as default missing value for output option
  * refactor(config): remove unnecessary newline from configs
* Tue Oct 31 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.4.0:
  * Support bumping the semantic version via `--bump`
  * Add 'typos' check
  * Log the output of failed external commands -
  * breaking change: Support regex in 'tag_pattern' configuration
  * Add field and value matchers to the commit parser
- Update service file to new obs service cargo requirements
- Add zstd in build requirements for tar scm
* Tue Sep 19 2023 Lubos Kocman <lubos.kocman@suse.com>
- Update license field based on legaldb review
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Sat May 20 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.2.0:
  * Update clap and clap extras to v4
  * Make the fields of Signature public
  * Add a custom configuration file for the repository
  * Support placing configuration inside pyproject.toml
  * Generate SBOM/provenance for the Docker image
  * Support using regex group values
  * [breaking] Nested environment config overrides
  * Set max of limit_commits to the number of commits
  * Set the node cache dependency path
  * Use the correct argument in release script
* Wed Jan 25 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.1.2:
  * Do not skip all tags when skip_tags is empty (#136)
  * Allow saving context to a file (#138)
  * Derive the tag order from commits instead of timestamp (#139)
  * Use timestamp for deriving the tag order (#139)
* Wed Jan 18 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.1.1:
  * Relevant change: Update README.md about the NPM package
  * Fix type casting in base NPM package
  * Rename the package on Windows
  * Disable liquid parsing in README.md by using raw blocks
  * Support for generating changelog for multiple git repositories
  * Publish binaries for more platforms/architectures
* Wed Dec 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.0.0:
  * Bug Fixes
  - Fix test fixture failures
  * Documentation
  - Fix GitHub badges in README.md
  * Features
  - [breaking] Replace --date-order by --topo-order
  - Allow running with --prepend and --output
  - [breaking] Use current time for --tag argument
  - Include completions and mangen in binary releases
  - Publish Debian package via release workflow
  * Miscellaneous Tasks
  - Run all test fixtures
  - Remove deprecated set-output usage
  - Update actions/checkout to v3
  - Comment out custom commit preprocessor
  * Refactor
  - Apply clippy suggestions
  * Styling
  - Update README.md about the styling of footer field
* Thu Nov 24 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.10.0:
  [#]## Bug Fixes
  - Warn against invalid tag range for `--current` flag ([#124](https://github.com/orhun/git-cliff/issues/124))
  - Use an alternative method to fetch registry
  - Fix syntax error in Dockerfile
  [#]## Documentation
  - Add MacPorts install info ([#111](https://github.com/orhun/git-cliff/issues/111))
  - Update badge URL for Docker builds
  [#]## Features
  - Do not skip breaking changes if configured ([#114](https://github.com/orhun/git-cliff/issues/114))
  - Changelog for the last n commits ([#116](https://github.com/orhun/git-cliff/issues/116))
  - Add a short variant `-d` for specifying `--date-order` flag
  [#]## Miscellaneous Tasks
  - Update versions in Dockerfile
  - Upgrade core dependencies
  [#]## Refactor
  - Improve cargo-chef caching in Dockerfile
  - Utilize workspace dependencies
* Mon Nov  7 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for git-cliff version 0.9.2
